#!/bin/bash

# grdsample /usr/local/gmt/cr_high.grd -Gg3.grd -R-84.0/-83.55/9.7/10.0
# grdsample /usr/local/gmt/int_high.grd -Gg3.int -R-84.0/-83.55/9.7/10.0
# grdgradient g3.grd -Gg3.int -A020 -Nt0.8


gmt gmtset MAP_FRAME_TYPE PLAIN
gmt gmtset PS_MEDIA legal
gmt gmtset FONT_TITLE 12,Helvetica,black
gmt gmtset FONT_ANNOT_PRIMARY 10,Helvetica,black
gmt gmtset FONT_ANNOT_SECONDARY 10,Helvetica,black
gmt gmtset FONT_LABEL 12,Helvetica,black

xlon1=-95
xlon2=-73
xlat1=2.0
xlat2=20.0

azim=45.3

gmt makecpt -Cseis -T-250/2/1.0 -Z > g.cpt  

cp nzonal3 zona_l
cp nzonar3 zona_r

cp zona_l contorno_placa.txt
cat zona_r >> contorno_placa.txt
head -n 1 zona_l >> contorno_placa.txt

#tail -n 1  ../lista_automatica_todos/lista_total.dat > epi.dat


# elon=`awk '{print $3}' epi.dat`
# elat=`awk '{print $4}' epi.dat`
# evfc=`awk '{print $1}' epi.dat`
# evhr=`awk '{print $2}' epi.dat`
# evdp=`awk '{print $5}' epi.dat`
# evmg=`awk '{print $6}' epi.dat`

elon=`awk '{print $1}' epi.dat`
elat=`awk '{print $2}' epi.dat`
evfc=`awk '{print 1900}' epi.dat`
evhr=`awk '{print 0.0}' epi.dat`
evdp=`awk '{print $3}' epi.dat`
evmg=`awk '{print 0}' epi.dat`

if [ -f mw.dat ]
then
  evmg=`cat mw.dat`
else
  echo "---" > mw.dat
fi



echo $elon $elat $evdp > epicentro.dat

gmt psbasemap -R-84/6.0/-84.5/14r -JOa-84/10.0/45.3/6i -B2/2NswE -P -K -X2i -Y6.5i   > p.ps
gmt pscoast -R -O -J -K -Glightyellow -Slightyellow >> p.ps
gmt psxy -R -J -B -W1 -K -O -G200 <<END>> p.ps
-84 6
-82.5 7
-83.0 8
-87.0 11.5
-89.0 10.0
-84 6
END



gmt psclip contorno_placa.txt -R -J -O -K >> p.ps
gmt grdimage -J -R-84/6.0/-84.5/14r -O -K -Cg.cpt data.nc >> p.ps  
gmt psxy -R -O -J -K mex_contours2.in -W1,255 >> p.ps
gmt psxy -R -O -J -K contorno_placa.txt -W3,255 >> p.ps
gmt grd2xyz data.nc > data.xyz
gmt project data.xyz  -C$elon/$elat -A$azim -G0.05 -N -L-10/10 > track
gmt pstext -R -O -J -K -Gblack -W0 -F+a270+f12p,Helvetica,white,+jBL <<END>>p.ps
-87 11.4 -20
-86.65 11.75 -60
-86.45 12. -100
END
gmt psclip -C -O -R -J -K >> p.ps

gmt psxy -R -O -J -K perimetro_zfp1.txt -Gp300/9  >> p.ps
gmt psxy -R -O -J -K perimetro_zfp2.txt -Gp300/8  >> p.ps
gmt psxy -R -O -J -K perimetro_cdnp.txt -Gp300/31 >> p.ps
gmt psxy -R -O -J -K escarpe_hess.txt -Gp300/30 >> p.ps

for k in fallas_listricas/*.falla
do
  psxy -R -O -J -K -W1 $k >> p.ps
done

gmt pstext -R -O -J -K -F+f16p,0,50/50/50,+jML   <<END>>p.ps
-84.1 11.2 Placa Caribe
-82.4 7.8 Microplaca Panam\341
-83.0 11.3  EH 
-83.5 10.5  SFL
END

gmt pstext -R -O -J -K -F+f16p,0,80/80/80,+jML   <<END>>p.ps
-87.5 10.2  Placa Cocos
END



gmt pstext -R -O -J -K -F+a-20+f16p,Helvetica,50/50/50,+jML   <<END>>p.ps
-81.9 9.2 C D N P
END

gmt pstext -R -O -J -K -F+a40+f14p,Helvetica,100/100/100,+jML   <<END>>p.ps
-83.15 6.9 ZFP
END

gmt psxy -R -J -O -K -W2,-  track >> p.ps
gmt grdtrack track -Gdata.nc  > corte.dat

gmt project -C-84.0/6.0 data.xyz -E$elon/$elat -G0.05 -N > track_v 
px1=-84.0
px2=$elon
py1=6.0
py2=$elat



gmt pscoast  -R-84/6.0/-84.5/14r -J -K -B -Df -W0.1 -A10 -T-82.0/10.5/0.6i -O -N1,2 -Lf-85/13/10/100+lkm>> p.ps

gmt pstext -R -J -O -F+a90+f10p,Helvetica-Bold,black,+jBR -K -W0.1i -Gwhite -TO <<END>> p.ps
-84.15 6.05 Laboratorio de Ingenier\355a S\355smica (UCR)
END

gmt psxy -R -J -O -K -Sa0.2i -G0 -W0.1 epicentro.dat >> p.ps
awk '{print $1+0.01,$2+0.01,-$3}' epicentro.dat | gmt psxy -R -J -O -Sa0.2i -Gred -W0.1 -K >> p.ps

xdist=`echo $px1 $px2 $py1 $py2 | awk '{print sqrt(($2-$1)*($2-$1)+($4-$3)*($4-$3))}'`
echo Distancia es $xdist
gmt project -C-84.0/6.0 data.xyz -E-89.1/11 -G0.05 -N > track_l 
awk '{print $1,$2,sqrt((e1-$1)*(e1-$1)+(e2-$2)*(e2-$2))}' e1=$elon e2=$elat track_l > estos
sort -n -k3 estos | head -n 1 > punto2


gmt project -C-84.5/14.0 data.xyz -E-79.4/9 -G0.05 -N > track_r
awk '{print $1,$2,sqrt((e1-$1)*(e1-$1)+(e2-$2)*(e2-$2))}' e1=$elon e2=$elat track_r > estos
sort -n -k3 estos | head -n 1 > punto3

ydist=`awk '{print $3}' punto2`
zdist=`awk '{print $3+h}' h=$ydist punto3`
echo $ydist -$evdp > punto.xy



gmt gmtselect zona_l -C0.03/track | head -n 1 > tt1
gmt gmtselect zona_r -C0.03/track | head -n 1 > tt2


gmt psscale -D-0.8i/2.2i/3.0i/0.2i -A -O -K -Cg.cpt -I -B50f25:"Profundidad de la Placa Cocos":/:"km": >> p.ps



if [ -s tt1 ] 
then


paste punto2 tt1 > ta
awk '{print sqrt(($1-$4)*($1-$4)+($2-$5)*($2-$5)),$3}' ta > punto_zona_l
paste punto2 tt2 > tb
awk '{print sqrt(($1-$4)*($1-$4)+($2-$5)*($2-$5)),$3}' tb > punto_zona_r

echo "Dmin = " $ydist
echo "Dmax = " $zdist
echo "Dmin zona l = " `cat punto_zona_l` 
echo "Dmax zona r = " `cat punto_zona_r`
awk '{if($3+v <= h2) print $3+v,$4}' v=$ydist h2=$zdist corte.dat > corte1

d1=`awk '{print $1}' punto_zona_l`
d2=`awk '{print $1}' punto_zona_r`


# psxy -R -J -O -K tt1 -Sc0.1 -G0 >> p.ps
# psxy -R -J -O -K tt2 -Sc0.1 -G0 >> p.ps


awk '{if($1>=da && $1<=db) print $1,$2}' da=$d1 db=$d2 corte1 > corte.xy
awk '{if($1>=da && $1<=db) print $1,$2-5}' da=$d1 db=$d2 corte1 > corte.xy.inf
awk '{if($1>=da && $1<=db) print $1,$2+20}' da=$d1 db=$d2 corte1 > corte.xy.sup

paste corte.xy.inf corte.xy.sup > bordes.corte

mprof=`gmtinfo -C -I1/5 corte.xy.inf | awk '{print $3}'`
echo "Max prof = " $mprof

mprof=-280
echo 0 0 > cuadro.txt
echo $zdist 0 >> cuadro.txt
echo $zdist $mprof >> cuadro.txt
echo 0 $mprof >> cuadro.txt
echo 0 0 >> cuadro.txt
gmt psxy -R0/$zdist/$mprof/0 -JX6i/1.5i -O -W1 -X0 -Y-1.7i -B0/a50f25g25:"Profundidad (km)":WSne cuadro.txt -K -G220 >> p.ps 

gmt psxy -R -J -O  -K -W1 -B corte.xy  >> p.ps 


moho_depth=-34.0
awk '{if(NR==1) print $1,0.0;if($2>=md && NR>1) print $1,$2 }' md=$moho_depth corte.xy > limite_moho.txt
gh1=`tail -n 1 corte.xy | awk '{if($2>=md) print $1,md}' md=$moho_depth`
echo Puntos son: $gh1
echo $gh1 >> limite_moho.txt
echo 10.0 $moho_depth >> limite_moho.txt
echo 10.0 0.0 >> limite_moho.txt
gmt psxy -R -O -J -K limite_moho.txt -Gp300/61:FblackBlightyellow -W1 >> p.ps


moho_depth_oceano=`head -n 1 corte.xy.inf | awk '{print $2}'`
moho1=`head -n 1 corte.xy | awk '{print $1}'`
echo -10.0 0.0 > limite_moho_oceano.txt
echo $moho1 0.0 >> limite_moho_oceano.txt
echo $moho1 $moho_depth_oceano >> limite_moho_oceano.txt
echo -10.0 $moho_depth_oceano >> limite_moho_oceano.txt
echo -10.0 0.0 >> limite_moho_oceano.txt
gmt psxy -R -O -J -K limite_moho_oceano.txt -G100 >> p.ps

cat corte.xy.inf > bloque_subduce
tac corte.xy.sup >> bloque_subduce
gmt psxy -R -O -J -K -G100 bloque_subduce >> p.ps

gmt psxy -R -JX -O -K -Sa0.2i -G0 punto.xy -N >> p.ps
awk '{print $1+0.01,$2+1}' punto.xy | psxy -R -J -O -K -Sa0.2i -W1 -Gred -N >> p.ps
gmt psxy -R -JX -O -K -Sc0.1 -W1 -G0 punto_zona_l  >> p.ps
gmt psxy -R -JX -O -K -Sc0.1 -W1 -G0 punto_zona_r  >> p.ps

else


  echo "Archivo tt1 esta vacio"
  echo "No se incluye zona de subduccion"
  mprof=`awk '{print $2+$2*0.5}' punto.xy`

  mprof=-280
  m1=100
  m2=50

mprof=-280
echo 0 0 > cuadro.txt
echo $zdist 0 >> cuadro.txt
echo $zdist $mprof >> cuadro.txt
echo 0 $mprof >> cuadro.txt
echo 0 0 >> cuadro.txt
gmt psxy -R0/$zdist/$mprof/0 -JX6/1.5 -O -W1 -X0 -Y-1.7 -B0/a50f25g25:"Profundidad (km)":WSne cuadro.txt -K -G220 >> p.ps 

axp=`awk '{if($1>=-83.0 && $2<=8.0) print 1;else print 0}' epicentro.dat`
if [ $axp == 1 ]
then
  echo Epicentro ubicado al sur de David, Panama
  gmt gmtselect zona_zfp_recta -C0.03/track | head -n 1 > tt3
  if [ -s tt3 ]
  then
    echo "Comprobando interseccion en ZFP"
  else
    echo -83.5 8.0 > tt3
  fi
  paste punto2 tt3 > tc
  awk '{print sqrt(($1-$4)*($1-$4)+($2-$5)*($2-$5)),$3}' tc > punto_zona_zfp

  moho_depth=-34.0
  awk '{print $1,md }' md=$moho_depth punto_zona_zfp > limite_moho_sur.txt
  echo 10.0 $moho_depth >> limite_moho_sur.txt
  echo 10.0 0.0 >> limite_moho_sur.txt
  awk '{print $1,0 }' punto_zona_zfp >> limite_moho_sur.txt
  awk '{print $1,md }' md=$moho_depth punto_zona_zfp >> limite_moho_sur.txt

  echo 0.0 0.0 > bloque_subduce
  echo 10.0 0.0 >> bloque_subduce
  echo 10.0 -15.0 >> bloque_subduce
  echo 0.0 -15.0 >> bloque_subduce
  echo 0.0 0.0 >> bloque_subduce

  gmt psxy -R -O -J -K -G100 bloque_subduce >> p.ps


  gmt psxy -R -O -J -K limite_moho_sur.txt -Gp300/61:FblackBlightyellow -W1 >> p.ps
  gmt psxy -R -J -O -W1 -B -Sa0.2i -G0 punto.xy -K >> p.ps 
  awk '{print $1+0.01,$2+1}' punto.xy | gmt psxy -R -J -O -K -Sa0.2i -W1 -Gred -N >> p.ps

else

  echo 0.0 0.0 > bloque_subduce
  echo 10.0 0.0 >> bloque_subduce
  echo 10.0 -15.0 >> bloque_subduce
  echo 0.0 -15.0 >> bloque_subduce
  echo 0.0 0.0 >> bloque_subduce

  gmt psxy -R -O -J -K -G100 bloque_subduce >> p.ps


  gmt gmtselect zona_zfp_recta -C0.03/track | head -n 1 > tt3
  paste punto2 tt3 > tc
  awk '{print sqrt(($1-$4)*($1-$4)+($2-$5)*($2-$5)),$3}' tc > punto_zona_zfp

  moho_depth=-34.0
  echo 
  awk '{print $1,md }' md=$moho_depth punto_zona_zfp > limite_moho_sur.txt
  echo 10.0 $moho_depth >> limite_moho_sur.txt
  echo 10.0 0.0 >> limite_moho_sur.txt
  awk '{print $1,0 }' punto_zona_zfp >> limite_moho_sur.txt
  awk '{print $1,md }' md=$moho_depth punto_zona_zfp >> limite_moho_sur.txt
  gmt psxy -R -O -J -K limite_moho_sur.txt -Gp300/10:FblackBlightyellow -W1 >> p.ps
  gmt psxy -R -J -O -W1 -B -Sa0.2i -G0 punto.xy -K >> p.ps 
  awk '{print $1+0.01,$2+1}' punto.xy | psxy -R -J -O -K -Sa0.2i -W1 -Gred -N >> p.ps


fi


fi


###########################################
#ASOCIAR EL EPICENTRO A UNA ZONA DADA
###########################################

gmt gmtselect epicentro.dat -Fplaca_cocos.txt > origen_cocos
gmt gmtselect epicentro.dat -Fperimetro_zfp1.txt > origen_zfp1
gmt gmtselect epicentro.dat -Fperimetro_zfp2.txt > origen_zfp2
gmt gmtselect epicentro.dat -Fperimetro_cdnp.txt > origen_cdnp
gmt gmtselect epicentro.dat -Flimon_norte.txt > origen_limon_norte
gmt gmtselect epicentro.dat -Fperimetro_subduccion.txt > origen_subduccion
gmt gmtselect epicentro.dat -Fperimetro_deformacion.txt > origen_deformacion
gmt gmtselect epicentro.dat -Fescarpe_hess.txt > origen_escarpe_hess

gmt psxy -R -J -O -W10 -K perimetro_subduccion.txt >> p.ps




origen="deformaci\363n de la corteza por fallamiento local"
f0=1

if [ -s origen_cocos ]
then
  origen="deformaci\363n interna en la Placa Cocos. El sismo se denomina como 'intraplaca' porque ocurre lejos de los bordes de la misma"
  echo El epicentro esta dentro de la Placa Cocos
  f0=0
fi


if [ -s origen_cdnp ]
then
  f0=0
  xdp=`echo -$evdp | awk '{if($1 > -5.0) print 1;else print 0}'`
  echo Entrando en la CDNP
  if [ $xdp == 1 ]
  then
    origen="deformaci\363n de la corteza por fallamiento local"
  else
    origen="fallamiento de la corteza asociado al Cintur\363n Deformado del Norte de Panam\341. Este marca el l\355mite de la Microplaca de Panam\341"
  fi
fi

if [ -s origen_limon_norte ]
then
  f0=0
  echo Origen es en Limon norte
  xdp=`echo -$evdp | awk '{if($1 > -10.0) print 1;else print 0}'`
  if [ $xdp == 1 ]
  then
    origen="deformaci\363n asociada al sistema de fallas l\345stricas del Caribe Norte. Estas son un tipo de falla normal que posee un \341ngulo de inclinaci\363n muy bajo"
  else
    origen="deformaci\363n de la corteza por fallamiento local"
  fi  
fi

if [ -s origen_subduccion ]
then
  f0=0
  echo Origen es probablemente subduccion. Revisando si hipocentro esta en la placa Cocos...

  x_critica=`tail -n 1 bordes.corte | awk '{print $1}'`
  x3=`echo $x_critica $ydist | awk '{if($1>$2) print 1;else print 0}'`

  if [ $x3 == 1 ]
  then

    x1=`awk '{if(xd>=$1) print $1,$2 }' xd=$ydist bordes.corte | tail -n 1`
    x2=`awk '{if(xd<=$3) print $3,$4 }' xd=$ydist bordes.corte | head -n 1`

    echo "Borde superior de la placa: " $x2
    echo "Borde inferior de la placa: " $x1
    echo "Posicion del hipocentro   : " $ydist -$evdp
    echo "x1= " $x1 " x2= " $x2 " evdp= " -$evdp
    xdp=`echo $x1 $x2 -$evdp | awk '{if($5>$2 && $5<=$4) print 1;else print 0}'`
    ydp=`echo $evdp | awk '{if($1<-$moho_depth) print 1; else print 0}'`
    zdp=`echo $x1 $x2 -$evdp | awk '{if($5<$2) print 1;else print 0}'`
    vdp=`echo $evdp | awk '{if($1>50) print 1;else print 0}'`

    echo "xdp es :" $xdp
    echo "ydp es :" $ydp
    echo "zdp es :" $zdp



    if [ $xdp == 1 ]
    then
      echo "El hipocentro ($ydist,-$evdp) SI esta entre los puntos ($x2) y ($x1) de la placa subducida"
      origen="subducci\363n de la Placa Cocos bajo la Placa Caribe"
      echo "El origen es subduccion"
      if [ $vdp == 1 ]
      then
        origen="deformaci\363n interna de la Placa Cocos."
        echo "El origen es deformacion de la placa por la profundidad mayor a 50 km"
      fi
    fi

    if [ $xdp == 0 ]
    then
      echo "El hipicentro ($ydist,-$evdp) NO esta entre los puntos ($x2) y ($x1) de la placa subducida"
      origen="deformaci\363n de la corteza por fallamiento local"
      echo "Cambiando origen a fallamiento local"
    fi  


    if [ $zdp == 1 ]
    then
      origen="deformaci\363n interna de la Placa Cocos. El hipocentro est\341 probablemente en el nivel inferior de la Placa Cocos"
      echo "Debido a la profundidad cambiando origen a deformacion interna"
    fi  
    if [ -s origen_deformacion ]
    then
      if [ $ydp == 1 ]
      then
        origen="deformaci\363n interna de la Placa Cocos"
      fi  
    fi
  else
    echo "El hipocentro esta mas a la derecha de donde termina la placa. No es subduccion"
    origen=" fallamiento local"
    echo "Cambiando origen a fallamiento local"    
  fi  
fi

if [ -s origen_escarpe_hess ]
then
  f0=0
  origen="fallamiento a lo largo del Escarpe de Hess. Esta es una estructura geol\363gica compuesta de fallas que se extiende hacia el interior de la Placa Caribe"
  echo "El epicentro esta en el escarpe de Hess"
fi

if [ -s origen_zfp1 ]
then
  f0=0
  origen="fallamiento a lo largo de la Zona de Fractura de Panam\341. Esta zona marca el l\355mite entre la Placa Cocos y la Placa Nazca"
  echo "El epicentro esta en la ZFP2"
fi

if [ -s origen_zfp2 ]
then
  f0=0
  origen="fallamiento a lo largo de la zona de Punta Burica hasta la Zona de Fractura de Panam\341. Generalmente los sismos que ocurren aqu\355 est\341n asociados a fallas de movimiento horizontal"
  echo "El epicentro esta en la ZFP1"
fi

echo "Profundidad es  -$evdp y condicion es $f0. El Moho esta a $moho_depth km."
x4=`echo -$evdp $f0 $moho_depth | awk '{if($3 > $1 && $2 == 1) print 1;else print 0}'`
echo -$evdp $f0 $moho_depth | awk '{if($3 > $1 && $2 == 1) print 1;else print 0}'
if [ $x4 == 1 ]
then
  origen="deformaciones internas de la placa."
  echo "La profundidad del hipocentro es muy grande, no puede ser local. Prof= $evdp"
fi

# 

gmt pstext -R0/3/0/5 -JX3i/4i -O -M -N -X-1.8i -Y-0.6i -K -F+f14p,Helvetica,+jBL <<EOF>> p.ps
> 0. -0.3 16p 7.8i j
El mapa de arriba muestra a color la profundidad de la zona de subducci\363n de la Placa Cocos bajo Costa Rica, cuya leyenda se da a mano izquierda. La parte de abajo muestra la proyecci\363n a profundidad de la traza punteada que pasa por el epicentro (estrella roja). 
> 0 -1.3  16p 7.8i j
Los rasgos tect\363nicos m\341s importantes son @%1%SFL@%%: Sistema de Fallas L\355stricas del Caribe Norte, @%1%CDNP@%%: Cintur\363n Deformado del Norte de Panam\341, @%1%ZFP@%%: Zona de Fractura de Panam\341, @%1%EH@%%: Escarpe de Hess.
> 0 -2.2  16p 7.8i j
@%1%@;250/0/0;Origen probable del sismo: @;;@%% El sismo del $evfc a las $evhr podr\355a estar asociado al proceso de @%1%@;0/0/250;$origen@;;@%%.
EOF


evpr=`echo $evdp | awk '{printf"%6.1f",$1}'`
gmt pstext -R0/1/0/10 -O -JX2i/1.5i -K -X-0.3i -Y7i -F+a0+f14p,Helvetica-Bold,black,+jLM  <<END>>p.ps
0.31 8.0  Epicentro
0.18 3.0  Mag(Mw):
0.18 1.0  Prof(km): 
END
# 
gmt pstext -R0/1/0/10 -O -JX2i/1.5i -K -X0 -Y0 -F+a0+f14p,Helvetica-Bold,black,+jRM  <<END>>p.ps
0.95 3.0  $evmg
0.95 1.0  $evpr
END

gmt psxy -R -O -Sa0.2i -Gred -W0.1 -J -K <<END>>p.ps
0.21 8.4 
END

gmt psxy -R -J -O <<END>>p.ps
END


convert p.ps -flatten -crop 600x895+0+10 mapa_origen.png

display mapa_origen.png &

#cp mapa_origen.png /var/www/img

rm estos origen_* punto* ta tb tt1 tt2 track* bloque_subduce
rm bordes.corte
rm cuadro.txt corte.xy*
rm gmt.conf

